@@ -53,7 +53,7 @@ class Cleanup(base.Base):
     default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
     help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
 )
-def cleanup(ctx, scenario_name):  # pragma: no cover
+def cleanup(ctx, scenario_name="default"):  # pragma: no cover
     """Use the provisioner to cleanup any changes made to external systems during \
     the stages of testing.
     """
