@@ -19,17 +19,17 @@
 #  DEALINGS IN THE SOFTWARE.
 """Base class used by init command."""
 
-from molecule import logger
-from molecule.command import base
-from molecule.command.init import role, scenario
+import logging
 
-LOG = logger.get_logger(__name__)
+from molecule.command import base
+from molecule.command.init import scenario
+
+LOG = logging.getLogger(__name__)
 
 
 @base.click_group_ex()  # type: ignore
 def init():  # pragma: no cover
-    """Initialize a new role or scenario."""
+    """Initialize a new scenario."""
 
 
-init.add_command(role.role)
 init.add_command(scenario.scenario)
