@@ -31,8 +31,7 @@ LOG = logging.getLogger(__name__)
 
 
 class Prepare(base.Base):
-    """
-    This action is for the purpose of preparing a molecule managed instance \
+    """This action is for the purpose of preparing a molecule managed instance \
     before the :py:class:`molecule.command.converge.Converge` action is run.
 
     Tasks contained within the ``prepare.yml`` playbook in the scenario
@@ -83,9 +82,8 @@ class Prepare(base.Base):
         molecule.yml.
     """
 
-    def execute(self):
-        """
-        Execute the actions necessary to prepare the instances and returns \
+    def execute(self, action_args=None):
+        """Execute the actions necessary to prepare the instances and returns \
         None.
 
         :return: None
