@@ -24,6 +24,7 @@ import logging
 import os
 import warnings
 from collections.abc import MutableMapping
+from pathlib import Path
 from uuid import uuid4
 
 from ansible_compat.ports import cache, cached_property
@@ -31,6 +32,7 @@ from packaging.version import Version
 
 from molecule import api, interpolation, platforms, scenario, state, util
 from molecule.app import app
+from molecule.data import __file__ as data_module
 from molecule.dependency import ansible_galaxy, shell
 from molecule.model import schema_v3
 from molecule.provisioner import ansible
@@ -42,7 +44,9 @@ MOLECULE_VERBOSITY = int(os.environ.get("MOLECULE_VERBOSITY", 0))
 MOLECULE_DIRECTORY = "molecule"
 MOLECULE_FILE = "molecule.yml"
 MOLECULE_KEEP_STRING = "MOLECULE_"
-DEFAULT_DRIVER = "delegated"
+DEFAULT_DRIVER = "default"
+
+MOLECULE_EMBEDDED_DATA_DIR = os.path.dirname(data_module)
 
 
 @cache
@@ -111,6 +115,7 @@ class Config(metaclass=NewInitCaller):
         self._run_uuid = str(uuid4())
         self.project_directory = os.getenv("MOLECULE_PROJECT_DIRECTORY", os.getcwd())
         self.runtime = app.runtime
+        self.scenario_path = Path(molecule_file).parent
 
     def after_init(self):
         self.config = self._reget_config()
@@ -331,7 +336,7 @@ class Config(metaclass=NewInitCaller):
         defaults = self._get_defaults()
         base_configs = filter(os.path.exists, self.args.get("base_config", []))
         for base_config in base_configs:
-            with util.open_file(base_config) as stream:
+            with open(base_config) as stream:
                 s = stream.read()
                 interpolated_config = self._interpolate(s, env, keep_string)
                 defaults = util.merge_dicts(
@@ -340,7 +345,7 @@ class Config(metaclass=NewInitCaller):
                 )
 
         if self.molecule_file:
-            with util.open_file(self.molecule_file) as stream:
+            with open(self.molecule_file) as stream:
                 s = stream.read()
                 interpolated_config = self._interpolate(s, env, keep_string)
                 defaults = util.merge_dicts(
@@ -380,7 +385,7 @@ class Config(metaclass=NewInitCaller):
                 "env": {},
             },
             "driver": {
-                "name": "delegated",
+                "name": "default",
                 "provider": {"name": None},
                 "options": {"managed": True},
                 "ssh_connection_options": [],
