@@ -32,7 +32,7 @@ LOG = logging.getLogger(__name__)
 class Delegated(Driver):
     r"""The class responsible for managing default instances.
 
-    Delegated is `not` the default driver used in Molecule.
+    Delegated is the default driver used in Molecule.
 
     Under this driver, it is the developers responsibility to implement the
     create and destroy playbooks.  ``Managed`` is the default behaviour of all
@@ -138,6 +138,8 @@ class Delegated(Driver):
     ```
     """
 
+    title = "Default driver, user is expected to manage provisioning of test resources."
+
     def __init__(self, config=None) -> None:
         """Construct Delegated."""
         super().__init__(config)
