@@ -255,7 +255,6 @@ class Ansible(base.Base):
           name: ansible
           config_options:
             defaults:
-              roles_path: /path/to/roles_path
               library: /path/to/library
               filter_plugins: /path/to/filter_plugins
             privilege_escalation: {}
@@ -463,12 +462,6 @@ class Ansible(base.Base):
         # top of the collection_path_list. This prevents dependency commands
         # from installing dependencies to user list of collections.
         collections_path_list = [
-            util.abs_path(
-                os.path.join(
-                    self._config.scenario.config.runtime.cache_dir,
-                    "collections",
-                ),
-            ),
             util.abs_path(
                 os.path.join(self._config.scenario.ephemeral_directory, "collections"),
             ),
@@ -500,9 +493,6 @@ class Ansible(base.Base):
             )
 
         roles_path_list = [
-            util.abs_path(
-                os.path.join(self._config.scenario.config.runtime.cache_dir, "roles"),
-            ),
             util.abs_path(
                 os.path.join(self._config.scenario.ephemeral_directory, "roles"),
             ),
@@ -593,16 +583,9 @@ class Ansible(base.Base):
         # ensure that all keys and values are strings
         env = {str(k): str(v) for k, v in env.items()}
 
-        roles_path = default_env["ANSIBLE_ROLES_PATH"]
         library_path = default_env["ANSIBLE_LIBRARY"]
         filter_plugins_path = default_env["ANSIBLE_FILTER_PLUGINS"]
 
-        try:
-            path = self._absolute_path_for(env, "ANSIBLE_ROLES_PATH")
-            roles_path = f"{roles_path}:{path}"
-        except KeyError:
-            pass
-
         try:
             path = self._absolute_path_for(env, "ANSIBLE_LIBRARY")
             library_path = f"{library_path}:{path}"
@@ -615,7 +598,6 @@ class Ansible(base.Base):
         except KeyError:
             pass
 
-        env["ANSIBLE_ROLES_PATH"] = roles_path
         env["ANSIBLE_LIBRARY"] = library_path
         env["ANSIBLE_FILTER_PLUGINS"] = filter_plugins_path
 
