@@ -20,6 +20,7 @@
 """Ansible-Playbook Provisioner Module."""
 
 import logging
+import shlex
 import warnings
 
 from molecule import util
@@ -86,17 +87,13 @@ class AnsiblePlaybook:
         else:
             ansible_args = []
 
-        self._ansible_command = util.BakedCommand(
-            cmd=[
-                "ansible-playbook",
-                *util.dict2args(options),
-                *util.bool2args(verbose_flag),
-                *ansible_args,
-                self._playbook,  # must always go last
-            ],
-            cwd=self._config.scenario.directory,
-            env=self._env,
-        )
+        self._ansible_command = [
+            "ansible-playbook",
+            *util.dict2args(options),
+            *util.bool2args(verbose_flag),
+            *ansible_args,
+            self._playbook,  # must always go last
+        ]
 
     def execute(self, action_args=None):
         """Execute ``ansible-playbook`` and returns a string.
@@ -113,11 +110,19 @@ class AnsiblePlaybook:
         with warnings.catch_warnings(record=True) as warns:
             warnings.filterwarnings("default", category=MoleculeRuntimeWarning)
             self._config.driver.sanity_checks()
-            result = util.run_command(self._ansible_command, debug=self._config.debug)
+            cwd = self._config.scenario_path
+            result = util.run_command(
+                cmd=self._ansible_command,
+                env=self._env,
+                debug=self._config.debug,
+                cwd=cwd,
+            )
 
         if result.returncode != 0:
+            from rich.markup import escape
+
             util.sysexit_with_message(
-                f"Ansible return code was {result.returncode}, command was: {result.args}",
+                f"Ansible return code was {result.returncode}, command was: [dim]{escape(shlex.join(result.args))}[/dim]",
                 result.returncode,
                 warns=warns,
             )
